package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````!14``#0````X@0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````J&X`
M`*AN```%```````!``$```#`?0``P'T!`,!]`0!\`@``K!(```8```````$`
M`@```,A]``#(?0$`R'T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`?0``P'T!`,!]`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!A````8@```&,`````````90```&8`````````9P```&@```!K
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````8!`````````#``<```````"``0```````P`1``P`````
M`````````!(```#:`0`````````````2````%```````````````$0`````"
M`````````````!$```!\`0`````````````2````&P``````````````$@``
M`+D!`````````````!(````C```````````````2````*@``````````````
M$@````T"`````````````!(```#%`0`````````````2````,P``````````
M````(````$X#`````````````"$```!+```````````````2````40``````
M````````$@```%@``````````````!(````;`P`````````````2````#`,`
M````````````$@```)("`````````````!(```!?```````````````2````
M,P(`````````````$@```&8``````````````!(```#'`@`````````````2
M````;0``````````````$@```'4``````````````!(```"P`@``````````
M```2````?0``````````````$@```(,``````````````!(```",````````
M```````@````!0,`````````````$@```*@``````````````!(```"M````
M```````````2````'@(`````````````$0```,X"`````````````!(```!@
M`@`````````````2````M```````````````$@```%("`````````````!(`
M``!R`P`````````````2````V0(`````````````$0```$T#````````````
M`!$```"$`@`````````````2````.@,`````````````$@```$\#````````
M`````!$```"[```````````````2````,@,`````````````$@```,0`````
M`````````!$```"*`0`````````````2````U@``````````````(@```.4`
M`````````````"````#[```````````````2````_0(`````````````$@``
M`'`"`````````````!(``````0`````````````2````!@$`````````````
M(````+L"`````````````!(````@`0`````````````2````J@$`````````
M````$@```"4!`````````````!(```"@`@`````````````2````F0$`````
M````````$@```"L!`````````````!(````\`0`````````````2````+@(`
M````````````$@```'X``````````````!(````_`@`````````````2````
M>0(`````````````$@```"L#`````````````!(```!"`0`````````````2
M````(P,`````````````$@```%8!`````````````!(````I`@``````````
M```2````Z`$`````````````$@```%T!`````````````!(```!D`0``````
M```````2````3`,`````````````(0```'4!`````````````!(```!R!```
M;)`!```````0`!(`1P,``'$3``"4`0``$@`)`/H!``!5,0```@```!(`"@"T
M`P``(1\``)`$```2``D`@@0```4F```X````$@`)`)$#``#I&@``!````!(`
M"0`F!```81````(````2``<`UP,``+$C``!4`@``$@`)`"P$```\@`$`````
M`!``$@!:!```[1H``%@!```2``D`#P0``#R``0``````$``2`*(#``"U'@``
M;````!(`"0#!`P``H1D``$`````2``D`R0,``&4>``!`````$@`)`.T#``#9
M+P``P@```!(`"0`"!```11P``!(````2``D`&P0``&R0`0``````$``2`'T$
M``!LD`$``````!``$@!7`P``(14``#@````2``D`.@0``%<<``":````$@`)
M`/@#```X@`$`!````!$`$0!3!```/(`!```````0`!$`%`0```45````````
M$@`)`",$``"=+P``/````!(`"0!@`P``I1X``!`````2``D`>P,``"D:``#`
M````$@`)`&<$``";,```N````!(`"0!Q!```;)`!```````0`!(`1@0``/$<
M``!T`0``$@`)``!L:6)P97)L+G-O`&]P96YD:7(`<W1D97)R`')E86QL;V,`
M86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K
M`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``
M;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P
M96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7W-T86-K7V-H:U]G=6%R9`!?
M7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S
M90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N
M;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!S
M=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?
M;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UA
M<FUV-RYS;RXQ`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D
M:7(`<W!R:6YT9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?
M7U]E;G9I<F]N`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S
M971U<%]L:6)P871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE
M86X`6%-?26YT97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L
M`'!A<E]B87-E;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?
M8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P
M87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L
M96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`P'T!`!<```#$
M?0$`%P```+Q_`0`7````R'\!`!<```#4?P$`%P````"``0`7````"(`!`!<`
M```,@`$`%P```!2``0`7````&(`!`!<````<@`$`%P```""``0`7````)(`!
M`!<````L@`$`%P```#"``0`7````.(`!`!<```#`?P$`%04``,1_`0`5!@``
MS'\!`!4.``#0?P$`%1\``-A_`0`5(P``W'\!`!4I``#@?P$`%2T``.1_`0`5
M,```Z'\!`!4R``#L?P$`%3,``/!_`0`5.```]'\!`!4]``#X?P$`%3X``/Q_
M`0`50P``Q'X!`!8#``#(?@$`%@0``,Q^`0`6!P``T'X!`!8(``#4?@$`%@D`
M`-A^`0`6"@``W'X!`!8+``#@?@$`%@P``.1^`0`6#0``Z'X!`!8.``#L?@$`
M%A```/!^`0`6$0``]'X!`!82``#X?@$`%A,``/Q^`0`6%````'\!`!85```$
M?P$`%A8```A_`0`6%P``#'\!`!88```0?P$`%AD``!1_`0`6&@``&'\!`!8;
M```<?P$`%AP``"!_`0`6'0``)'\!`!8>```H?P$`%B```"Q_`0`6(0``,'\!
M`!8B```T?P$`%B0``#A_`0`6)0``/'\!`!8F``!`?P$`%B<``$1_`0`6*```
M2'\!`!8K``!,?P$`%BP``%!_`0`6+@``5'\!`!8O``!8?P$`%C$``%Q_`0`6
M,@``8'\!`!8S``!D?P$`%C0``&A_`0`6-0``;'\!`!8V``!P?P$`%C<``'1_
M`0`6.0``>'\!`!8Z``!\?P$`%CL``(!_`0`6/```A'\!`!8_``"(?P$`%D``
M`(Q_`0`600``D'\!`!9"``"4?P$`%D0``)A_`0`610``G'\!`!9&``"@?P$`
M%D<``*1_`0`62```J'\!`!9)``"L?P$`%DH``+!_`0`62P``M'\!`!9,``"X
M?P$`%DX```&UO>@!0'!'!.`MY03@G^4.X(_@"/"^Y4!N`0``QH_B%LJ,XD#^
MO.4`QH_B%LJ,XCC^O.4`QH_B%LJ,XC#^O.4`QH_B%LJ,XBC^O.4`QH_B%LJ,
MXB#^O.4`QH_B%LJ,XAC^O.4`QH_B%LJ,XA#^O.4`QH_B%LJ,X@C^O.4`QH_B
M%LJ,X@#^O.4`QH_B%LJ,XOC]O.4`QH_B%LJ,XO#]O.4`QH_B%LJ,XNC]O.4`
MQH_B%LJ,XN#]O.4`QH_B%LJ,XMC]O.4`QH_B%LJ,XM#]O.4`QH_B%LJ,XLC]
MO.4`QH_B%LJ,XL#]O.4`QH_B%LJ,XKC]O.4`QH_B%LJ,XK#]O.4`QH_B%LJ,
MXJC]O.4`QH_B%LJ,XJ#]O.4`QH_B%LJ,XIC]O.4`QH_B%LJ,XI#]O.4`QH_B
M%LJ,XHC]O.4`QH_B%LJ,XH#]O.5X1\!&`,:/XA;*C.)T_;SE`,:/XA;*C.)L
M_;SE`,:/XA;*C.)D_;SE`,:/XA;*C.)<_;SE`,:/XA;*C.)4_;SE`,:/XA;*
MC.),_;SE`,:/XA;*C.)$_;SE`,:/XA;*C.(\_;SE`,:/XA;*C.(T_;SE`,:/
MXA;*C.(L_;SE`,:/XA;*C.(D_;SE`,:/XA;*C.(<_;SE`,:/XA;*C.(4_;SE
M`,:/XA;*C.(,_;SE`,:/XA;*C.($_;SE`,:/XA;*C.+\_+SE`,:/XA;*C.+T
M_+SE`,:/XA;*C.+L_+SE`,:/XA;*C.+D_+SE`,:/XA;*C.+<_+SE`,:/XA;*
MC.+4_+SE`,:/XA;*C.+,_+SE`,:/XA;*C.+$_+SE`,:/XA;*C.*\_+SE`,:/
MXA;*C.*T_+SE>$?`1@#&C^(6RHSBJ/R\Y0#&C^(6RHSBH/R\Y7A'P$8`QH_B
M%LJ,XI3\O.4`QH_B%LJ,XHS\O.4`QH_B%LJ,XH3\O.4`QH_B%LJ,XGS\O.4`
MQH_B%LJ,XG3\O.4`QH_B%LJ,XFS\O.4`QH_B%LJ,XF3\O.4`QH_B%LJ,XES\
MO.4`QH_B%LJ,XE3\O.4`QH_B%LJ,XDS\O.5PM8BPS>D&$`62!JD%J@>H34S_
M]USO34M\1.-8`Y-,2P.:XU@11AA&!)/_]\3N24OC6!YX2$OE6'ZY__<2[T=*
M>D0081"Y`2#_]U+O__=T[RAH__>F[X#X/6<H:/_WH.^0^)XS0_`"`X#XGC,H
M:/_WF.^0^)XS0_`!`X#XGC,'F`4PL/&`3P?3-4LV2.-8>$091@.3__=J[H``
M__="[P:<,4HA:'I$`6`P29!@>41!8"])`T9Y1`EH@6`N27E$0/@,'P0A46`!
M(0>:BD(UW``@`O&`00,Q*$U#^"$`)TD`D'U$`S)Y1"AI__>4[@1&&+DH:?_W
M"N\$1B%-?40H:?_WSNX@2'A$`/`C^6"YZV@CN1U(>$0`\!SYZ&`<2WM$V&@(
ML0'PM_@:2WM$&&G_]TKO__?X[2!&"+!PO53X(5`!,4#X!%_!YP"_+&L!`$0!
M``!``0``#`$``"`!``"D;`$`)`$``,D=``!`;`$`_A\``!!L`0#Q'P``!&P!
M`(D%``#J:P$`I1T``$P=``#(:P$`O&L!`$_P``M/\``.`TEY1&A&(/`/#.5&
M`/`"^+9H`0`?M0E+"4I[1)I8`I((2II8`Y(`(@&2!TJ;6`(=`),!:`*;`YC_
M]VCNCFD!`!P!```$`0``$`$```A("4L)2GA$>T2#0GI$@K`%T`=+TU@!DPNQ
M`K`81P*P<$<`O]IJ`0#8:@$`4&D!`!@!```*2`M+>$1[1!D:B1`)2@'KT7%)
M$'I$@K`%T`=+TU@!DPNQ`K`81P*P<$<`OZAJ`0"F:@$`%&D!`#@!```.2Q"U
M>T0.3!MX?$2CN0U+XU@CL0Q+>T08:/_W,N[_][?_"DOC6!NQ"4AX1/_W>.T!
M(@A+>T0:<!"]`+]L:@$`XF@!`#`!```>:@$`%`$``*Y8```\:@$`"+4'2P=*
M>T2;6"NQ!DD'2'E$>$3_]P[NO>@(0*;G`+^.:`$`-`$```QJ`0!N6```&4LM
MZ?!'>T0/1H!&4+,72IM8'&@<LP-&FD83^`$;4;DF1JKK"`HU1E;X!)NY\0`/
M!-%,1A/@/2GRT.WG4D9!1DA&__=R[0`H[=$9^`HP/2OIT2T;K1`*\0$$/6!,
M1"!&O>CPAP1&^N=>:`$`*`$``!.U"$L(2GM$G%AI1B-H`9/_][[_`9HC:)I"
M`=#_]SSN`K`0O>YG`0`L`0``][4&1F]&#TP/2WQ$Y5@K:`&3.48P1O_WI?\H
MN0&:*VB:0@W0__<B[@A+`)KC6!MH`^N"`UIH0_@$*P`J^M'HYP.P\+V^9P$`
M+`$``"@!```MZ?!/#4;?^!R11TOY1%GX`S"%L`"3&V@'1@.3"W@]*PB_`34H
M1O_W].T"J8!&.$;_]W#_!$:0L?_WZNU`13_3`3P5^`$[!/@!/P`K^=$`(`";
M`YH;:)I"8-#_]^#M,TM9^`.@VO@`L%OX)#![N3!+IAQ[1!IHM@!:L3%&6$;_
M]W+LRO@``*"Y3_#_,.#G`33JYP$B,$8:8/_WQ.P!D``H\M"F\0@"64;_]\+L
M`9O*^``PVO@`,!Y$`"-&^`0\`I0[1AA&$_@!*PJQ/2KYT1=+"/$""%GX`T#`
M&T!$W?@(D"9H__>@[$;X*0``*,S0(V@"FE/X(C`91A?X`2L!^`$K"K$]*@C1
M/2(:<!7X`2L#^`$O`"KYT9KG"T;LYP6PO>CPCP"_;&<!`"P!```H`0``IF@!
M`"WI\$\O2S!*>T2?6)VP.V@%1AN3P+$#>+.Q__?XZP9&D+'?^*B`W_BHD-_X
MJ*#X1/E$^D0P1O_W..Q8N3!&__=V["A&__?^[!N:.VB:0C;0__=*[0#Q$P1!
M1B!&__<>[``HY]!)1B!&__<8[``HX=`H1O_W-.V#1B!&__<P[5A$`C#_]S;L
M@T8C1BI&44;_]P[M:4981O_W\.P!,%A&"]`$FP/T<$.S]8!/!='_]ZC_6$;_
M]]SLO>?_]Q3L^.<=L+WH\(\\9@$`+`$``.<8``#D&```Y1@``#"U$TL32GM$
MG%B=L"-H:48%1AN3__<8[*BY!)L#]'!#L_6`3P+0L_4@3P;1`B$H1O_WGNNP
M^H#P0`D;FB-HFD(#T/_WYNP`(/?G';`PO0"_9F4!`"P!```3M0I,"DM\1.-8
M&&C_][#L"$L)2>-8>40!DPA+`9I[1`*PO>@00/_WE;P`OPYE`0`@`0``/`$`
M`-<7``":%P``$[4,2PQ*>T2<6"!H__>0[/_WUO\@:/_WC.P`(@=+"$E[1,WI
M`#('2GE$>D3_]V#K`K`0O<YD`0`@`0``&1H``*$7``"C"0``<+4K2RM*>T2>
M6*WU`%V&L#-H#?4`4A0R$V#_]U[K)DLF2GM$`ZP`DWI$`T9!\@$!($;_]S3K
M0QP*T0`C&$8-]0!3%#,::#-HFD(MT/_W<.RP]8!?`-G_W@WU@%40-2!&3_2`
M4BE&__?*ZP0>Y=M@'/_W8NL#1@`HW]"H0@+2`AF50NC3JT("V2H9DT+CTT'R
M`0*40M_<(D881BE&__<P[``B`T8"5<GG#?4`70:P<+V&9`$`+`$``(`7``!N
M%P``__>>ORWI\$])2TI*>T2M]81=FUB!L`1&1T@#DPWU@U(;:!PR>$0-1A-@
M__?5_2\A!T8@1O_W9.MXL4!((49X1/_W"/X-]8-3'#,::`.;($8;:)I"9M#_
M]PSL($;_]P+L-TF`1GE$*$;_]]CK!D;?^-20W_C4H-_XU+#Y1/I$^T0`+MK0
M,G@`*@B_3D97L3%&.$;_]\CJ*+DM27E$__>^ZP9&[><P1O_WWNL`)3!$@1L0
M^`$M+RH4T`CQ`0(*1++U@%^ZVA^MS>D`M#-&4D9/](!1*$;_]X+J`3"P]8!?
M`MG_W@5PX^<$KC%&*$;_]XCKH+DS:0/T<$.S]0!/#M$!(2A&__=FZDBY$D@I
M1GA$__>A_2A&__?6Z@1&D^<.20`@>42[YPWUA%T!L+WH\(\`O\!C`0`L`0``
MPA8``+$6``"8%@``(Q8``%D7``"`%@``8A8``.,5``#<%0```T83^`$K`KEP
M1R\J"+\81O?G$+4$1@BQ`W@KN1](>$2]Z!!`__>>NO_W;NL!."!$A$(#1AW2
M&G@!."\J^-`:1A+X`1DO*1'1`3N<0AI&`](1>`$[+RGXT!(;DQRS]8!?&=@!
M,K+U@%\.V?_>E$(31N73G$+HT2-X+RL"T0A(>$3.YPA(>$3+YP=+(49[1!A&
M__>LZA"]`"#\YP"_(Q4``,,4```>%0``F&,!`'"U0TM#2GM$BK">6&I&0DDS
M:'E$"9,!\2H$`?$*`Q5&&&A9:`@S`\6C0BI&]]$;B#I(*X!X1/_WX?PY2#E,
M>$3_]]S\.$A\1'A$__?7_#=(>$3_]]/\-DAX1/_WS_PU2'A$__?+_#1(>$3_
M]\?\,TAX1/_WP_P@1O_WP/PP2'A$__>\_"](>$3_][C\+DAX1/_WGOP!1A"Q
M($;_]]?\*TAX1/_WE?P!1ABQ*4AX1/_WS?PH2'A$__>+_`%&>+$F2'A$__?#
M_"5))4AY1'A$__>]_`F:,VB:0AC0__?&ZB%(>$3_]W7\`480L1](>$3HYQY)
M"B)Y1`WQ$0#_]\;I`"CAT1M(#?$;`7A$VN<*L'"]OF$!`"P!``!6%```Q!0`
M`,,4``#Y%```P10``,(4``#!%```R10``'84``#%%```RQ0``&$4``#%%```
MQ!0``,H4``#-%```'A0``.,4``!-%```L10``$D4``"N%```+10```BU"TM[
M1!MH`3,,T0E(>$3_]R3\(+$`>!"Q,#@8OP$@!4M[1!A@!4M[1!AH"+T`OYAA
M`0"S$P``>F$!`'1A`0`(M?_W7NK_]ZKI`+$`:`B]][463P1&?T0X1O_W__LA
M1@5&"+$#>"NY$4AX1`.PO>CP0#'D__=TZ;"Y($;_]S3J!D8H1O_W,.HP1`(P
M__<VZ09&"$L(20"5>41[1")&__<,ZC%&.$;AYP.P\+WE$P``T1,``.82``#!
M$P``+>GP3ZWU`$V_L#ZLI/%<"$5&W_@`E-_X`#3Y1%GX`S#?^/CC!),-]0!"
M&VC^1/0R$V`.\1`,#O$$`Z3Q=`8'1I/H!P"&Z`<`O.@/``_%G.@#``[Q*`ZD
M\6@*A>@#`)[H!P"*Z`<`[DAX1/_WF?L%1IBQ`WB+L?_WC?\H1O_W!ND%1@WU
M`$/T,QIH!)LH1AMHFD(`\+J!__?0Z?_W<_\%1BBY6O@$"P`H3-'>37U$*$;_
M][SI0``!,/_WPNB"1H-&V4L!/7M$%?@!+P`J1-%8^`2[N_$`#TC1N_$`#US0
M6$;_]Z3I!4901O_WH.D%1`7R!$4H1O_WI.@&1LQ+S$E[1`"3S$M:1GM$>43-
M^`2@__=VZ4_TX'$P1O_W2.D!,$31__<^Z0-H$2L_T,-*PTE9^`(``),Z:#-&
M>40`:/_W!ND`)9[G__<L^P`HJM`#>``KI]#_]YSHHN<91EA&!9,+\0(+__=,
MZ06;K>=81O_W&/L%1@`HJ]`#>``KJ-#_]U3\`"BDT"A&__>"Z(-&I.<H1O_W
M2OP`*/715O@$6QVQ*W@`*_31F^>K1IGGI/'@"$%&,$;_]U[H@D90L9]+H$E9
M^`,`.F@S1GE$`&C_]\#HM^?8^!`P`_1P0[/U@$_MT=CX&+#_]S#I@T7GT=CX
M$###\P@#L_7@?^#1*$;_]R+H!4:02'A$__?,^@`H?='7^`"02$;_]PSI`RB`
M1A[9BDD$.'E$2$3^]^+ON+FX\00/!-#(1!CX!3PO*P_1?VAOL3A&__?TZ`,H
M"-F`200X>40X1/[WS.\`*`B_N4;_]W/^@$8`*$#PG8`!1DA&__<6Z(%&`"@`
M\)6`3_`""D_P_S-O\!$"S?@`H"<?_O>D[P8B.49(1O_W=.@4^`0\`"M!T7MX
M0RL^T;MX02L[T?MX0RLXT3MY2"LUT7MY12LRT4_P_S-O\#D"S?@`H$A&_O>$
M[RDB.49(1O_W4N@R1EU+74E[1,WI`'-<2WE$>T0H1O_WAN@P1O_W9.A92"E&
M>$3_]X[Z*$;_]T?^O.;7^`"`_O>^[P%&0$;_]UK\@48`*'_T>*]TYP`C`"(`
MDTA&`"/^]U+O`/"D_H)&3_0`0CE&2$;_]Q[H`AXGW$A&I/%$!__W"N@P/%%&
M.$8`\!#_H4;?^`"A^D0@1A?X`2M11@CQ`0C_]T;HN/$4#P3Q`@3RT0`CB?@H
M,#A+.$E[1,WI`),W2S)&>T1Y1*GG.4901@#PC?[*YS-)-$AY1'A$__<X^O[W
M&.\Q2S))>T3-Z0`#,4LR1GM$>40H1O_W&N@N3"]/W_B\@'Q$?T3X1$_TX'$H
M1O[WYN\!,(71_O?<[P-H$2N`T?[W^.X*\0$*`)#-Z0&H(T8R1CE&*$;^]_KO
MY><-]0!-/["]Z/"/>E\!`"P!``"T8`$`1A(``.,2``#2$@``IA(``),2``#`
M$0``"`$``'$2```>$@``B!$``!<2``#P$0``&Q(``%L1``#>#P``M`\``#80
M``!S$0``KQ```#8/``#9#P``7P\``$41``"0$```"`\``/8.``",$```)1$`
M`"WI^$^`2X%*>T2<6"!H_O>H[P5&(&C^]Z3OE?AD,(#X93![2'A$__=S^2"Q
M`W@Q*P'10W@+L?_W@_P@:/[WD.]T20LC`2)Y1/[W\.XXNR!H_O>&[W!)`R,!
M(GE$_O?F[@5&`"ADT2!H_O=Z[VM)`R,!(GE$_O?:[@5&`"A]T&A(>$3_]T7Y
M!D8`*&?0(&C^]VCO,D;K:!EH_O?4[FW@`27#:-_X@)&?:=_X?*'Y1-GX!#`%
M\?\XJT(@:`C=_O=0[P`C0D8Y1O[W7.X&1D"Y5TM[1%IH`3J01;G1`28=1B+@
MV?@(,`)H4_@EL)-H"NH#`[/U@&\'T=%H6$;^]S#N`"CET0$UT^<@:/[W*N\Q
M:`(C`"+^]S[O`4;NY_[W(N\Y1O[WVNT!-FMH(&BS0O7<CN<@:/[W%N_K:#U*
M&6AZ1/[W@N[K:!MHFVA;`HS5(&C^]PCOZV@9:/[W(.Z$Y__WC/H&1B!HEK/^
M]_SNZV@R1AEH_O=H[C!&_O?:[B!H_O?P[@5&(&C^]^SN*DD!(GE$_O>V[2E*
M`49Z1"A&_O=4[B!H_O?>[@`C@/AE,"1()$QX1/_WKOA\1.!@@+F@:/_WV/S@
M8%BY'TAX1/[WL.W^]\CN'4M[1)IHZV@2:%SG&TQ/].!Q?$3@:/[WFNX1*`-&
M"=!"'`$J!MD62-3I`A():'A$_O>4[;WH^(_\6@$`(`$``#4.``"9#P``B@\`
M`'D/``"G#0``^%L!```$(`#46P$`J@X``&$.``!L#@``<`P``/!:`0!"#@``
MTEH!`,):`0`K#@``.+4$1O_W)?O_]QK[!4;_]R?\<+%LL2-X6[$&22A&>43^
M]\[MA4($T2!&O>@X0/_W';DXO:(,```MZ?!/_DO_2M6P>T2;6`.J%$8!DQMH
M`/%<!5.3`/$<`U/X!!L)NIU"1/@$&_C10"011@UJ2VL$,FM`C6@):&M`2T!/
MZO-S`3S38_'1@VCJ20"3`ZL<:`)I#$30^`S`%$0`FM#X`.""Z@P&0FA=:$_J
ML@D60`":#42"Z@D(".H."$_JO@J&Z@P&B.H""&5$FF@$Z_YD-$2H1`">B>H*
M!25`"D0(Z_1H,D1/ZK0$WFB%Z@D%%42*Z@0"`NH(`@Y$3D2"Z@H"!>OX93)$
M3^JX"!YIA.H("0+K]6)?:0Y$">H%"4_JM06R1(GJ!`F(Z@4&T4060`?K`0I4
M1(;J"`8F1)QI">OR:4_JL@*%Z@(+#$0&Z_EFH$0+Z@D+W&E/ZKD)@NH)"HOJ
M!0L*Z@8*#$0L1,-$BNH""@OK]FNB1$_JM@8<:HGJ!@@,1`CJ"P@*Z_MJ(D1/
MZKL+76J(Z@D(ANH+!)!$".OZ:)IJ!.H*!`U$3^JZ"DU$B^H*"71`">H("0I$
M,D0L1(GJ"PD$Z_ADD41/ZK@(VFJ*Z@@%">OT:0I$'FLE0$_JM`231(CJ!`*%
MZ@H%`NH)`@Y$5D1=1(+J"`(%Z_EE,D1/ZKD)7FN$Z@D+`NOU8I]K#D0+Z@4+
M3^JU!;!$B^H$"XGJ!0;#1!9`!^L!"$1$ANH)!B9$W&L+Z_)K3^JR`H7J`@@,
M1`;K^V:A1`CJ"P@<;$_JNPN"Z@L*B.H%"`KJ!@H,1"Q$R$2*Z@(*".OV:*)$
M3^JV!EQLB^H&"0Q$">H("0KK^&HB1$_JN`B=;(GJ"PF&Z@@$D40)Z_IIVFP$
MZ@H$#41/ZKH*742(Z@H+"^H)"Q%$,41T0(OJ"`LL1(M$'6U>203K^60-1$_J
MN0E:;:A$BNH)!0OK]&ME0`I$3^JT!)YMJ$221(GJ!`((Z_MH@NH+`@Y$3^J[
M"Y)$L43:;83J"P:&Z@@&"NOX:@I$3^JX"+%$'FX41(OJ"`()Z_II@NH*`@Y$
M3^JZ"EUN%$2S1(CJ"@8$Z_EDANH)!@U$3^JY"9INLT2H1(KJ"04+Z_1K94`*
M1$_JM`2H1))$W6Z)Z@0"@NH+`@CK^V@-1$_JNPN21!IOJ42$Z@L%"NOX:H7J
M"`4*1$_JN`@41(OJ"`*"Z@H"%$1:;ZE$">OZ:0I$3^JZ"IYODT2(Z@H"@NH)
M`@3K^60.1$_JN0F31-IOL$2*Z@D&"^OT:V9`"D1/ZK0$T_B`4+!$DD2)Z@0"
M".O[:(+J"P(-1$_JNPN21*E$T_B$((3J"P6%Z@@%"NOX:@I$3^JX"*E$T_B(
M4-/XC&`41(OJ"`()Z_II@NH*`@U$3^JZ"JM$#D2(Z@H%%$0$Z_EDL$2%Z@D%
M".``OYEY@EJAZ]EN;E@!`"P!``#3^)!@3^JY"8KJ"0)=1`7K]&4.1&)`3^JT
M!+)$B>H$!FY`LD33^)1@0D0"Z_5B#D1/ZK4%L42$Z@4&5D"Q1-/XF&`*Z_)J
M#D1/ZK("-$2%Z@(&ANH*!C1$T_B<8`GK^FDQ1$_JN@H-1(+J"@$$Z_ED@>H)
M`4_JN0E*Z@D(#40(Z@0("NH)`=/XH&!(Z@$(_4D%Z_1E#D1/ZK0$,D1)Z@0+
MD$0+Z@4+">H$`DOJ`@O3^*0@".OU:`I$3^JU!5)$1.H%"@3J!08*Z@@*2NH&
M"M/XJ&"31`OK^&L.1$_JN`A.1$7J"`*R1`+J"P(%Z@@&,D/3^*Q@"NO[:@Y$
M3^J["S1$2.H+!B)$!NH*!@CJ"P0F0]/XL$`"Z_IB3^JZ"@Q$2^H*"25$">H"
M"0OJ"@1)Z@0)T_BT0"Y$!NOR9@Q$3^JR`D1$2NH""`KJ`@4(Z@8(2.H%"-/X
MN%"A1`GK]FD-1$_JM@9=1$+J!@2H1`3J"00"Z@8%+$/3^+Q0".OY:`U$3^JY
M"=/XP'"J1$;J"0541`7J"`4&Z@D*!.OX9$7J"@5/ZK@(!^L!"E)$2>H("Q5$
M"^H$"PGJ"`)+Z@(+T_C$(`7K]&5/ZK0$"D1(Z@0*%D0*Z@4*".H$`DKJ`@K3
M^,@@LT0+Z_5K"D1/ZK4%2D1$Z@4)!.H%!@GJ"PE)Z@8)T_C,8))$"NO[:@Y$
M3^J["T9$1>H+"`7J"P((Z@H(L41(Z@((T_C0(`GK^FE/ZKH*2^H*!@I$(D0&
MZ@D&"^H*!"9#T_C40)!$".OY:`Q$3^JY"2Q$2NH)!0KJ"0(%Z@@%)D050]/X
MV"`&Z_AF3^JX"`I$2>H(!)-$-$`)Z@@"%$/3^-P@740%Z_9E"D1/ZK8&T_C@
M<))$2.H&`E1$*D`(Z@8*!.OU9$+J"@)/ZK4%!^L!"M%$1NH%"I%$"NH$"@;J
M!0)*Z@(*T_CD(`GK]&D*1$_JM`1"1-/XZ'`*ZP((1>H$`@7J!`H"Z@D"0NH*
M`@?K`0H(Z_EHT_CL<$_JN0E61!9$1.H)`@+J"`HY1`3J"0)*Z@("#4051-/X
M\!!;2@;K^&811$_JN`@,1(GJ"`%Q0`Q$T_CT$`7K]F411$_JM@:)1(CJ!@%I
M0(E$T_CX$`3K]61/ZK4*T_C\4!%$3^JT"Q5$B$2&Z@H!">OT:6%`+D33^`!!
MBNH+!87J"06(1`CK^6C3^`013^JY"2Y$I1A51(OJ"0H&Z_AFC!B*Z@@*3^JX
M"%Q$B>H("XOJ!@NC1-/X"$&J1$_JM@$*Z_9J%$33^`QAH42(Z@$$"^OZ:X3J
M"@061$_JN@K3^!!1L$2!Z@H&ANH+!J%$">O[:;!$3^J["ZX8T_@400Y$BNH+
M`8'J"0$(Z_EH%$1/ZKD)#D33^!@1HD2+Z@D$!NOX9H3J"`011$_JN`BB1(M$
MT_@<08GJ"`%Q0`KK]FH41(M$3^JV`=/X(&&A1(CJ`00+Z_IKA.H*!!9$3^JZ
M"M/X)%&P1('J"@:&Z@L&H40)Z_MIL$1/ZKL+KAC3^"A!#D2*Z@L!@>H)`0CK
M^6@41`/@W+P;C];!8LI/ZKD)#D33^"P1HD2+Z@D$!NOX9A%$A.H(!$_JN`B+
M1(GJ"`%Q0(M$T_@P$:)$"NOV:A%$3^JV!HE$B.H&`8'J"@&)1-/X-!$+Z_IK
M$41/ZKH*B$2&Z@H!@>H+`8A$T_@X$=/X/#$)Z_MI$41/ZKL+#D031(KJ"P$(
MZ_EH@>H)`7-$3^JY"9I$B^H)`PY$@^H(`P;K^&931`/K]F,#8$-H'D0`FT9@
M`^NX!PSK"0/#8`-IAV!;1`-A`9M3FAMHFD(!T/[WXNE5L+WH\(\(M6`@_O?>
MZ`I*"TD"8`+QB#)"8`+Q*4*B]982HO:+8H)@HO&(,L)@`"+`Z002@F'"90B]
M`2-%9_#ATL,MZ?!!%D8%1D-IT@";&"B_@FE#822_`3*"88-I!?$<!P/K5G.#
M8<!M\+'`\4`$M$(X1*B_-$:(0@/2`QF90@#2_]Z(0@'K!`@!V4!%^-,B1O[W
M?NGK;2-$0"OK92_1*$;_]P#[048V&P7Q7`@6X+E"`=E!1>33N4(!\4`#`=*?
M0M[3#$8Z1E3X!!N<0D+X!!OYT2A&__?F^B%&0#X_+N;<N4("V;L9F4+*T[E"
M`M*+&9]"Q=,R1CA&_O=*Z>YEO>CP@2WI\$$!\1P'2VF.:0Q&@"&3^H/XP_/%
M`UH<."H%1C:Z^50'ZP(`0]W"\4`"`"'^]SCH($;_][7Z."(`(3A&_O<PZ"!&
MQ.D5:/_WJ_KC>"!&*W!CB&MP(V@;"JMP(VCK<.-Y*W'CB&MQ8V@;"JMQ8VCK
M<>-Z*W)CB6MRHV@;"JMRHVCK<N-[*W/CB6MSXV@;"JMSXVCK<^-\*W1CBFMT
M(VD;"JMT(VGK=+WH\$'^]\>XPO$X`@`APN<`OP&UO>@!0'!'<&5R;'AS:2YC
M`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@```N+@`E<R\E<P!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/
M3U0`+W!R;V,O)6DO)7,`97AE`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`
M4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%
M`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]
M`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`"5S)7,E<R5S`'!A<BT`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ
M5D524TE/3@`Q+C`T.0!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`%5315(`55-%4DY!344`5$5-
M4$1)4@!435``+W1M<`!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>
M3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I4
M14U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]
M/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*
M8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I
M;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*
M?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D
M("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`](")<;E!!4BYP
M;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^
M("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G
M)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<
M)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I
M.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R
M(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D
M<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G
M:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O
M<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I
M(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA
M9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I
M8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O<RP@,"D["G)E860H
M7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*2D[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C
M:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD
M9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?
M1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D
M('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG
M(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B
M87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ
M*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O
M7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F
M:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE
M)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?
M1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D
M;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&EN9F\M/GMB
M=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN
M9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I
M92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR
M971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO
M="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S
M7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@
M("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R
M(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@
M97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@
M9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO
M="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A
M=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@
M<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U
M;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@
M9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)
M3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM
M>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D
M;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@
M)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF
M("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E
M9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI
M;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H
M(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@
M)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H
M1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T
M96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H
M<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?
M;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@
M)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S
M92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C
M:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*
M)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E
M.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F
M:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&
M:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!
M<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D[
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D
M97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]
M+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!0
M05(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![
M(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@
M>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H
M:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H
M.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U
M:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*
M?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP
M(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6
M>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@
M*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E
M<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I
M;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE
M;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]
M"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U53
M15)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@
M)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH
M(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A
M)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA
M;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E
M:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D
M8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D
M("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D
M9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@
M/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O
M9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]("\O("1M=&EM93L*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E
M*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0
M?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD
M<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L
M("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R
M7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M
M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E
M;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I
M;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H
M;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE
M*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*
M?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M
M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@
M;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]
M"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE
M("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I
M<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\
M(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG
M971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T
M<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````A%@``R14```$````!`````0```.@"```/````
MC@0```P```!A$```#0```%4Q```9````P'T!`!L````$````&@```,1]`0`<
M````!````/7^_V\L`0``!0```-0(```&````%`(```H```"L!```"P```!``
M```5``````````,```"X?@$``@```/`!```4````$0```!<```!P#@``$0``
M`(`-```2````\````!,````(````&`````````#[__]O`0``"/K__V\0````
M`````````````````````````````````````````````````````,A]`0``
M`````````&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0
M``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!``
M`&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```
M:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H
M$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0``!H$```:!```&@0
M``!H$```:!```&@0``!H$```:!```&@0``!H$```<1,`````````````53$`
M````````````81``````````````````````````````````````````````
M````````````@`$`_____SXT``"),0```````&HR``!C,@``,C0``(`R```Z
M-````````"0T```I-````````$,T``!'0T,Z("A!;'!I;F4@."XS+C`I(#@N
M,RXP`$$R````865A8FD``2@````%-RU!``8*!T$(`0D""@02!!,!%`$5`1<#
M&`$:`AP!'@0B`0`N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI
M`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T
M97,`````````````````````````````````````````````````````````
M"P````$````"````%`$``!0!```8```````````````!`````````!,```#V
M__]O`@```"P!```L`0``Z`````,`````````!`````0````=````"P````(`
M```4`@``%`(``,`&```$`````P````0````0````)0````,````"````U`@`
M`-0(``"L!``````````````!`````````"T````)`````@```(`-``"`#0``
M\`````,`````````!`````@````V````"0```$(```!P#@``<`X``/`!```#
M````$`````0````(````/P````$````&````8!```&`0```(````````````
M```"`````````#H````!````!@```&@0``!H$```"`,`````````````!```
M``0```!%`````0````8```!P$P``<!,``.0=``````````````0`````````
M2P````$````&````5#$``%0Q```(```````````````"`````````%$````!
M`````@```%PQ``!<,0``2#T``````````````0````````!9`````0````(`
M``"D;@``I&X```0```````````````0`````````8P````X````#````P'T!
M`,!]```$```````````````$````!````&\````/`````P```,1]`0#$?0``
M!```````````````!`````0```![````!@````,```#(?0$`R'T``/`````$
M``````````0````(````A`````$````#````N'X!`+A^``!(`0``````````
M```$````!````(D````!`````P````"``0``@```/```````````````!```
M``````"/````"`````,````\@`$`/(```#`0``````````````0`````````
ME`````$````P`````````#R````:```````````````!`````0```)T````#
M``!P``````````!6@```,P```````````````0`````````!`````P``````
>````````B8```*T```````````````$`````````
